from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="salesforce-agentforce",
    version="0.1.9",
    author="Amir Khan",
    author_email="amir.khan@salesforce.com",
    description="A Python SDK for interacting with the Agentforce Agents",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/amirkhan-ak-sf/agentforce",
    packages=find_packages(include=['agentforce', 'agentforce.*']),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    python_requires=">=3.7",
    install_requires=[
        "requests>=2.25.0",
    ],
)